# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.2-v202603250858-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ColumnRuleAssetCreatorInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _column_index: int
    _column_index_data_id: Optional[int]
    _description: Optional[str]
    _identity_id: Optional[str]
    _is_root: Optional[bool]
    _permission_string: Optional[str]
    _scoped_to: Optional[str]


    def __init__(
        self,
        column_index: Optional[int] = None,
        column_index_data_id: Optional[int] = None,
        description: Optional[str] = None,
        identity_id: Optional[str] = None,
        is_root: Optional[bool] = None,
        permission_string: Optional[str] = None,
        scoped_to: Optional[str] = None,
    ) -> None: ...

    @property
    def column_index(self) -> int: ...

    @column_index.setter
    def column_index(self, column_index: int) -> None: ...

    @property
    def column_index_data_id(self) -> Optional[int]: ...

    @column_index_data_id.setter
    def column_index_data_id(self, column_index_data_id: Optional[int]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def identity_id(self) -> Optional[str]: ...

    @identity_id.setter
    def identity_id(self, identity_id: Optional[str]) -> None: ...

    @property
    def is_root(self) -> Optional[bool]: ...

    @is_root.setter
    def is_root(self, is_root: Optional[bool]) -> None: ...

    @property
    def permission_string(self) -> Optional[str]: ...

    @permission_string.setter
    def permission_string(self, permission_string: Optional[str]) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
