# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.2-v202603250858-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ValidateCronOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _error: Optional[str]
    _next_run_time: Optional[str]
    _quartz_cron_expression: Optional[str]
    _quartz_cron_expression_summary: Optional[str]
    _valid: Optional[bool]


    def __init__(
        self,
        error: Optional[str] = None,
        next_run_time: Optional[str] = None,
        quartz_cron_expression: Optional[str] = None,
        quartz_cron_expression_summary: Optional[str] = None,
        valid: Optional[bool] = False,
    ) -> None: ...

    @property
    def error(self) -> Optional[str]: ...

    @error.setter
    def error(self, error: Optional[str]) -> None: ...

    @property
    def next_run_time(self) -> Optional[str]: ...

    @next_run_time.setter
    def next_run_time(self, next_run_time: Optional[str]) -> None: ...

    @property
    def quartz_cron_expression(self) -> Optional[str]: ...

    @quartz_cron_expression.setter
    def quartz_cron_expression(self, quartz_cron_expression: Optional[str]) -> None: ...

    @property
    def quartz_cron_expression_summary(self) -> Optional[str]: ...

    @quartz_cron_expression_summary.setter
    def quartz_cron_expression_summary(self, quartz_cron_expression_summary: Optional[str]) -> None: ...

    @property
    def valid(self) -> Optional[bool]: ...

    @valid.setter
    def valid(self, valid: Optional[bool]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
