# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.2-v202603250858-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ColumnRuleSetItemPropertyInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_index_item': 'int',
        'column_index_value': 'int',
        'property_name': 'str'
    }

    attribute_map = {
        'column_index_item': 'columnIndexItem',
        'column_index_value': 'columnIndexValue',
        'property_name': 'propertyName'
    }

    def __init__(self, column_index_item=None, column_index_value=None, property_name=None):
        """
        ColumnRuleSetItemPropertyInputV1 - a model defined in Swagger
        """

        self._column_index_item = None
        self._column_index_value = None
        self._property_name = None

        if column_index_item is not None:
          self.column_index_item = column_index_item
        if column_index_value is not None:
          self.column_index_value = column_index_value
        if property_name is not None:
          self.property_name = property_name

    @property
    def column_index_item(self):
        """
        Gets the column_index_item of this ColumnRuleSetItemPropertyInputV1.
        The index of the column that references the item. The column index is 1-based

        :return: The column_index_item of this ColumnRuleSetItemPropertyInputV1.
        :rtype: int
        """
        return self._column_index_item

    @column_index_item.setter
    def column_index_item(self, column_index_item):
        """
        Sets the column_index_item of this ColumnRuleSetItemPropertyInputV1.
        The index of the column that references the item. The column index is 1-based

        :param column_index_item: The column_index_item of this ColumnRuleSetItemPropertyInputV1.
        :type: int
        """
        if column_index_item is None:
            raise ValueError("Invalid value for `column_index_item`, must not be `None`")

        self._column_index_item = column_index_item

    @property
    def column_index_value(self):
        """
        Gets the column_index_value of this ColumnRuleSetItemPropertyInputV1.
        The index of the column that contains the value to set for the property. The column index is 1-based

        :return: The column_index_value of this ColumnRuleSetItemPropertyInputV1.
        :rtype: int
        """
        return self._column_index_value

    @column_index_value.setter
    def column_index_value(self, column_index_value):
        """
        Sets the column_index_value of this ColumnRuleSetItemPropertyInputV1.
        The index of the column that contains the value to set for the property. The column index is 1-based

        :param column_index_value: The column_index_value of this ColumnRuleSetItemPropertyInputV1.
        :type: int
        """
        if column_index_value is None:
            raise ValueError("Invalid value for `column_index_value`, must not be `None`")

        self._column_index_value = column_index_value

    @property
    def property_name(self):
        """
        Gets the property_name of this ColumnRuleSetItemPropertyInputV1.
        The property to set on an item

        :return: The property_name of this ColumnRuleSetItemPropertyInputV1.
        :rtype: str
        """
        return self._property_name

    @property_name.setter
    def property_name(self, property_name):
        """
        Sets the property_name of this ColumnRuleSetItemPropertyInputV1.
        The property to set on an item

        :param property_name: The property_name of this ColumnRuleSetItemPropertyInputV1.
        :type: str
        """
        if property_name is None:
            raise ValueError("Invalid value for `property_name`, must not be `None`")

        self._property_name = property_name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ColumnRuleSetItemPropertyInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
