# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.2-v202603250858-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class PutScalarsInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _datasource_class: str
    _datasource_id: str
    _force_calculated_scalars: Optional[bool]
    _scalars: List[PutScalarInputV1]


    def __init__(
        self,
        datasource_class: Optional[str] = None,
        datasource_id: Optional[str] = None,
        force_calculated_scalars: Optional[bool] = False,
        scalars: Optional[List[PutScalarInputV1]] = None,
    ) -> None: ...

    @property
    def datasource_class(self) -> str: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: str) -> None: ...

    @property
    def datasource_id(self) -> str: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: str) -> None: ...

    @property
    def force_calculated_scalars(self) -> Optional[bool]: ...

    @force_calculated_scalars.setter
    def force_calculated_scalars(self, force_calculated_scalars: Optional[bool]) -> None: ...

    @property
    def scalars(self) -> List[PutScalarInputV1]: ...

    @scalars.setter
    def scalars(self, scalars: List[PutScalarInputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
